@@ -34,6 +34,7 @@ typedef enum {
 	MAILBOX_IMAP
 } MailboxType;
 
+extern GtkTooltips *panel_tooltips;
 
 typedef struct _MailCheck MailCheck;
 struct _MailCheck {
@@ -218,6 +219,7 @@ get_remote_password (void)
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
 	entry = gtk_entry_new ();
+	gtk_entry_set_visibility (GTK_ENTRY (entry), FALSE);
 	gtk_box_pack_start (GTK_BOX (hbox), entry, FALSE, FALSE, 0);
 	gtk_widget_show_all (hbox);
 
@@ -410,6 +412,8 @@ mailcheck_load_animation (MailCheck *mc, const char *fname)
 		return FALSE;
 	else if (mc->frames == 3)
 		mc->report_mail_mode = REPORT_MAIL_USE_BITMAP;
+	else
+		mc->report_mail_mode = REPORT_MAIL_USE_ANIMATION;
 	mc->nframe = 0;
 
 	gdk_pixbuf_render_pixmap_and_mask(pb,
@@ -440,6 +444,24 @@ static void
 after_mail_check (MailCheck *mc)
 {
 	static const char *supinfo[] = {"mailcheck", "new-mail", NULL};
+	char *text;
+	
+	if (mc->anymail){
+		if(mc->mailbox_type == MAILBOX_LOCAL) {
+			if(mc->newmail)
+				text = g_strdup(_("You have new mail."));
+			else
+				text = g_strdup(_("You have mail."));
+		}
+		else {
+			if(mc->unreadmail)
+				text = g_strdup_printf(_("%d/%d messages"), mc->unreadmail, mc->totalmail);
+			else
+				text = g_strdup_printf(_("%d messages"), mc->totalmail);
+		} 
+	}
+	else
+		text = g_strdup_printf(_("No mail."));
 
 	if(mc->newmail) {
 		if(mc->play_sound)
@@ -489,30 +511,14 @@ after_mail_check (MailCheck *mc)
 		gtk_widget_queue_draw (mc->da);
 
 		break;
-	case REPORT_MAIL_USE_TEXT: {
-		char *text;
-
-		if (mc->anymail){
-			if(mc->mailbox_type == MAILBOX_LOCAL) {
-				if(mc->newmail)
-					text = g_strdup(_("You have new mail."));
-				else
-					text = g_strdup(_("You have mail."));
-			}
-			else {
-				if(mc->unreadmail)
-					text = g_strdup_printf(_("%d/%d messages"), mc->unreadmail, mc->totalmail);
-				else
-					text = g_strdup_printf(_("%d messages"), mc->totalmail);
-			} 
-		}
-		else
-			text = g_strdup_printf(_("No mail."));
+	case REPORT_MAIL_USE_TEXT:
 		gtk_label_set_text (GTK_LABEL (mc->label), text);
-		g_free(text);
 		break;
 	}
-	}
+
+	gtk_tooltips_set_tip (panel_tooltips, GTK_WIDGET (mc->applet),
+			      text, NULL);
+	g_free(text);
 }
 
 static gboolean
@@ -729,7 +735,7 @@ animation_selected (GtkMenuItem *item, gpointer data)
 	
 	load_new_pixmap (mc);
 	panel_applet_gconf_set_string(mc->applet, "animation-file", 
-				      mc->animation_file, NULL);
+				      mc->animation_file ? mc->animation_file : "", NULL);
 }
 
 static void
@@ -1457,20 +1463,11 @@ check_callback (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 static void
 applet_load_prefs(MailCheck *mc)
 {
-	gchar *query;
-
-	query = gnome_program_locate_file (
-			NULL, GNOME_FILE_DOMAIN_PIXMAP,
-			"mailcheck/email.png", FALSE, NULL);
-
 	mc->animation_file = panel_applet_gconf_get_string(mc->applet, "animation-file", NULL);
-	if(!mc->animation_file || strcmp(mc->animation_file, "none")) {
+	if(!mc->animation_file) {
 		g_free(mc->animation_file);
-		mc->animation_file = g_strdup(query);
+		mc->animation_file = NULL;
 	}
-
-	g_free(query);
-
 	mc->update_freq = panel_applet_gconf_get_int(mc->applet, "update-frequency", NULL);
 	mc->pre_check_cmd = panel_applet_gconf_get_string(mc->applet, "exec-command", NULL);
 	mc->pre_check_enabled = panel_applet_gconf_get_bool(mc->applet, "exec-enabled", NULL);
@@ -1481,7 +1478,7 @@ applet_load_prefs(MailCheck *mc)
 	mc->remote_server = panel_applet_gconf_get_string(mc->applet, "remote-server", NULL);
 	mc->pre_remote_command = panel_applet_gconf_get_string(mc->applet, "pre-remote-command", NULL);
 	mc->remote_username = panel_applet_gconf_get_string(mc->applet, "remote-username", NULL);
-	if(!mc->remote_username || strcmp(mc->remote_username, "none")) {
+	if(!mc->remote_username) {
 		g_free(mc->remote_username);
 		mc->remote_username = g_strdup(g_getenv("USER"));
 	}
@@ -1495,6 +1492,9 @@ static void
 mailcheck_about(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
 	MailCheck *mc = data;
+	GdkPixbuf *pixbuf = NULL;
+	gchar *file;
+
 	static const gchar     *authors [] =
 	{
 		"Miguel de Icaza <miguel@kernel.org>",
@@ -1503,6 +1503,10 @@ mailcheck_about(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 		"Lennart Poettering <poettering@gmx.net>",
 		NULL
 	};
+	const char *documenters [] = {
+	  NULL
+	};
+	const char *translator_credits = _("translator_credits");
 
 	if (mc->about != NULL)
 	{
@@ -1511,15 +1515,20 @@ mailcheck_about(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 		return;
 	}
 	
+	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-mailcheck.png", TRUE, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (file, NULL);
+	g_free (file);
+	
 	mc->about = gnome_about_new (_("Mail check Applet"), "1.1",
 				     _("(c) 1998-2000 the Free Software Foundation"),
 				     _("Mail check notifies you when new mail arrives in your mailbox"),
 				     authors,
-				     NULL,
-				     NULL,
-				     NULL);
-	gtk_window_set_wmclass (GTK_WINDOW (mc->about),
-				"mailcheck", "Mailcheck");
+				     documenters,
+   				     strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				     pixbuf);
+				     
+	gtk_window_set_wmclass (GTK_WINDOW (mc->about), "mailcheck", "Mailcheck");
+	
 #ifdef FIXME
 	gnome_window_icon_set_from_file (GTK_WINDOW (mc->about),
 					 GNOME_ICONDIR"/gnome-mailcheck.png");
