@@ -28,6 +28,10 @@
 
 #include "pager.h"
 
+/* even 16 is pretty darn dubious. */
+#define MAX_REASONABLE_ROWS 16
+#define DEFAULT_ROWS 1
+
 typedef struct {
 	GtkWidget *applet;
 
@@ -160,13 +164,15 @@ num_rows_changed (GConfClient *client,
 		  GConfEntry  *entry,
 		  PagerData   *pager)
 {
-	int n_rows = 2; /* Default value */
+	int n_rows = DEFAULT_ROWS;
 	
 	if (entry->value != NULL &&
 	    entry->value->type == GCONF_VALUE_INT) {
 		n_rows = gconf_value_get_int (entry->value);
 	}
-	
+
+        n_rows = CLAMP (n_rows, 1, MAX_REASONABLE_ROWS);
+        
 	pager->n_rows = n_rows;
 	pager_update (pager);
 
@@ -287,15 +293,21 @@ fill_pager_applet(PanelApplet *applet)
 	error = NULL;
 	pager->n_rows = panel_applet_gconf_get_int (applet, "num_rows", &error);
 	if (error) {
+                g_printerr (_("Error loading num_rows value for workspace switcher applet: %s\n"),
+                            error->message);
 		g_error_free (error);
-		pager->n_rows = 2; /* Default value */
+                /* leave current value */
 	}
 
+        pager->n_rows = CLAMP (pager->n_rows, 1, MAX_REASONABLE_ROWS);
+
 	error = NULL;
 	display_names = panel_applet_gconf_get_bool (applet, "display_workspace_names", &error);
 	if (error) {
+                g_printerr (_("Error loading display_workspace_names value for workspace switcher applet: %s\n"),
+                            error->message);
 		g_error_free (error);
-		display_names = FALSE; /* Default value */
+                /* leave current value */
 	}
 
 	if (display_names) {
@@ -307,8 +319,10 @@ fill_pager_applet(PanelApplet *applet)
 	error = NULL;
 	pager->display_all = panel_applet_gconf_get_bool (applet, "display_all_workspaces", &error);
 	if (error) {
+                g_printerr (_("Error loading display_all_workspaces value for workspace switcher applet: %s\n"),
+                            error->message);
 		g_error_free (error);
-		pager->display_all = TRUE; /* Default value */
+                /* leave current value */
 	}
 	
 	pager->size = panel_applet_get_size (applet);
@@ -377,7 +391,7 @@ display_help_dialog (BonoboUIComponent *uic,
 {
 	GError *error = NULL;
 
-	gnome_help_display_desktop (NULL, "pager", "pager", NULL, &error);
+	gnome_help_display_desktop (NULL, "workspace-switcher", "workspace-switcher", NULL, &error);
 	if (error) {
 		g_warning ("help error: %s\n", error->message);
 		g_error_free (error);
@@ -390,7 +404,7 @@ display_about_dialog (BonoboUIComponent *uic,
 		      const gchar       *verbname)
 {
 	static GtkWidget *about = NULL;
-	GdkPixbuf *pixbuf;
+	GdkPixbuf *pixbuf = NULL;
 	gchar *file;
 	
 	static const gchar *authors[] =
@@ -398,6 +412,10 @@ display_about_dialog (BonoboUIComponent *uic,
 		"Alexander Larsson <alla@lysator.liu.se>",
 		NULL
 	};
+	const char *documenters [] = {
+	  NULL
+	};
+	const char *translator_credits = _("translator_credits");
 
 	if (about != NULL) {
 		gtk_widget_show (about);
@@ -405,21 +423,16 @@ display_about_dialog (BonoboUIComponent *uic,
 		return;
 	}
 
-	pixbuf = NULL;
-
-	/* TODO: This should not use gnome-clock! */
-	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-clock.png", TRUE, NULL);
-	if (!file) {
-		g_warning (G_STRLOC ": gnome-clock.png cannot be found");
-		pixbuf = gdk_pixbuf_new_from_file (file, NULL);
-	}
+	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-workspace.png", TRUE, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (file, NULL);
+	g_free(file);
 
 	about = gnome_about_new (_("Workspace Switcher"), "1.0",
 				 _("(c) 2001 Red Hat, Inc."),
 				 _("The Workspace Switcher shows you a small version of your workspaces that lets you manage the windows."),
 				 authors,
-				 NULL, /* documenters */
-				 NULL, /* translator_credits */
+				 documenters,
+				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				 pixbuf);
 	
 	gtk_window_set_wmclass (GTK_WINDOW (about), "pager", "Pager");
@@ -472,9 +485,9 @@ update_workspaces_model (PagerData *pager)
 	int nr_ws, i;
 	WnckWorkspace *workspace;
 	GtkTreeIter iter;
-	
+
 	nr_ws = wnck_screen_get_workspace_count (pager->screen);
-	
+        
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (pager->num_workspaces_spin), nr_ws);
 
 	gtk_list_store_clear (pager->workspaces_store);
@@ -500,6 +513,8 @@ workspace_created (WnckScreen    *screen,
 		   WnckWorkspace *space,
 		   PagerData     *pager)
 {
+        g_return_if_fail (WNCK_IS_SCREEN (screen));
+        
 	update_workspaces_model (pager);
 	g_signal_connect (G_OBJECT (space), "name_changed",
 			  (GCallback) workspace_renamed, pager);
@@ -510,6 +525,7 @@ workspace_destroyed (WnckScreen    *screen,
 		     WnckWorkspace *space,
 		     PagerData     *pager)
 {
+        g_return_if_fail (WNCK_IS_SCREEN (screen));
 	update_workspaces_model (pager);
 }
 
@@ -636,10 +652,10 @@ setup_dialog (GladeXML  *xml,
 	g_signal_connect (G_OBJECT (pager->num_workspaces_spin), "value_changed",
 			  (GCallback) num_workspaces_value_changed, pager);
 	
-	g_signal_connect_swapped (pager->screen, "workspace_created",
-				  (GCallback) workspace_created, pager);
-	g_signal_connect_swapped (pager->screen, "workspace_destroyed",
-				  (GCallback) workspace_destroyed, pager);
+	g_signal_connect (pager->screen, "workspace_created",
+                          (GCallback) workspace_created, pager);
+	g_signal_connect (pager->screen, "workspace_destroyed",
+                          (GCallback) workspace_destroyed, pager);
 
 	pager->workspaces_store = gtk_list_store_new (1, G_TYPE_STRING, NULL);
 	update_workspaces_model (pager);
