@@ -49,6 +49,9 @@ typedef struct {
 	GtkWidget *always_group_radio;
 	GtkWidget *move_minimized_radio;
 	GtkWidget *change_workspace_radio;
+
+	/* gconf listeners id */
+	guint listeners [3];
 } TasklistData;
 
 static void display_properties_dialog (BonoboUIComponent *uic,
@@ -145,9 +148,17 @@ applet_change_pixel_size (PanelApplet  *applet,
 }
 
 static void
-destroy_tasklist(GtkWidget * widget, gpointer data)
+destroy_tasklist(GtkWidget * widget, TasklistData *tasklist)
 {
-	/* TasklistData *tasklist = data; */
+	GConfClient *client = gconf_client_get_default ();
+
+	gconf_client_notify_remove (client, tasklist->listeners[0]);
+	gconf_client_notify_remove (client, tasklist->listeners[1]);
+	gconf_client_notify_remove (client, tasklist->listeners[2]);
+	
+	tasklist->listeners[0] = 0;
+	tasklist->listeners[1] = 0;
+	tasklist->listeners[2] = 0;
 }
 
 static const BonoboUIVerb tasklist_menu_verbs [] = {
@@ -328,7 +339,7 @@ setup_gconf (TasklistData *tasklist)
 
 	key = panel_applet_gconf_get_full_key (PANEL_APPLET (tasklist->applet),
 					       "display_all_workspaces");
-	gconf_client_notify_add(client, key,
+	tasklist->listeners[0] = gconf_client_notify_add(client, key,
 				(GConfClientNotifyFunc)display_all_workspaces_changed,
 				tasklist,
 				NULL, NULL);
@@ -336,7 +347,7 @@ setup_gconf (TasklistData *tasklist)
 
 	key = panel_applet_gconf_get_full_key (PANEL_APPLET (tasklist->applet),
 					       "group_windows");
-	gconf_client_notify_add(client, key,
+	tasklist->listeners[1] = gconf_client_notify_add(client, key,
 				(GConfClientNotifyFunc)group_windows_changed,
 				tasklist,
 				NULL, NULL);
@@ -344,7 +355,7 @@ setup_gconf (TasklistData *tasklist)
 
 	key = panel_applet_gconf_get_full_key (PANEL_APPLET (tasklist->applet),
 					       "move_unminimized_windows");
-	gconf_client_notify_add(client, key,
+	tasklist->listeners[2] = gconf_client_notify_add(client, key,
 				(GConfClientNotifyFunc)move_unminimized_windows_changed,
 				tasklist,
 				NULL, NULL);
@@ -469,7 +480,7 @@ display_about_dialog (BonoboUIComponent *uic,
 		      const gchar       *verbname)
 {
 	static GtkWidget *about = NULL;
-	GdkPixbuf *pixbuf;
+	GdkPixbuf *pixbuf = NULL;
 	gchar *file;
 	
 	static const gchar *authors[] =
@@ -477,6 +488,10 @@ display_about_dialog (BonoboUIComponent *uic,
 		"Alexander Larsson <alla@lysator.liu.se>",
 		NULL
 	};
+	const char *documenters [] = {
+	  NULL
+	};
+	const char *translator_credits = _("translator_credits");
 
 	if (about != NULL) {
 		gtk_widget_show (about);
@@ -484,21 +499,16 @@ display_about_dialog (BonoboUIComponent *uic,
 		return;
 	}
 
-	pixbuf = NULL;
-
-	/* FIXME: This should not use gnome-clock! */
-	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-clock.png", TRUE, NULL);
-	if (!file) {
-		g_warning (G_STRLOC ": gnome-clock.png cannot be found");
-		pixbuf = gdk_pixbuf_new_from_file (file, NULL);
-	}
+	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-windows.png", TRUE, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (file, NULL);
+	g_free(file);
 
 	about = gnome_about_new (_("Window List"), "1.0",
 				 _("(c) 2001 Red Hat, Inc"),
 				 _("The Window List shows a list of all visible windows and let you browse them."),
 				 authors,
-				 NULL, /* documenters */
-				 NULL, /* translator_credits */
+				 documenters,
+				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				 pixbuf);
 	
 	gtk_window_set_wmclass (GTK_WINDOW (about), "tasklist", "Tasklist");
