@@ -162,11 +162,6 @@ kill_free_drawers (void)
 	g_slist_free (to_destroy);
 }
 
-static void
-session_notify_global_changes (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data) {
-	panel_session_init_global_config ();
-}
-
 static const struct poptOption options[] = {
   {"profile", '\0', POPT_ARG_STRING, &profile_name, 0, N_("Specify a profile name to load"), NULL},
   {NULL, '\0', 0, NULL, 0}
@@ -185,7 +180,7 @@ main(int argc, char **argv)
 	 */
 	putenv ("BONOBO_ACTIVATION_DEBUG_OUTPUT=1");
 
-	gnome_program_init ("panel", VERSION,
+	gnome_program_init ("gnome-panel", VERSION,
 			    LIBGNOMEUI_MODULE,
 			    argc, argv,
 			    GNOME_PARAM_POPT_TABLE, options,
@@ -193,25 +188,20 @@ main(int argc, char **argv)
 			    NULL);
 
 	bonobo_activate ();
-	
-	if (profile_name == NULL) {
-		/* FIXME: Do this properly. just a temporary hack */
-		session_set_current_profile ("default");
-	} else {
-		session_set_current_profile (profile_name);
-	}
 
+	panel_gconf_setup_profile (profile_name);
+	
 	if (!panel_shell_register ())
 		return -1;
 	find_kde_directory();
 
 	client = gnome_master_client ();
 
-	/* FIXME - get the session stuff working properly */
+	panel_session_set_restart_command (client, argv [0]);
 
-	g_signal_connect (G_OBJECT (client), "save_yourself",
+	g_signal_connect (client, "save_yourself",
 			  G_CALLBACK (panel_session_save), argv[0]);
-	g_signal_connect (G_OBJECT (client), "die",
+	g_signal_connect (client, "die",
 			  G_CALLBACK (panel_session_die), NULL);
 
 	panel_tooltips = gtk_tooltips_new ();
@@ -221,7 +211,9 @@ main(int argc, char **argv)
 
 	panel_gconf_add_dir ("/apps/panel/global");
 	panel_gconf_add_dir ("/desktop/gnome/menus");
-	panel_gconf_notify_add ("/apps/panel/global", session_notify_global_changes, NULL);
+	panel_gconf_notify_add ("/apps/panel/global", panel_global_config_notify, NULL);
+
+	status_applet_create_offscreen ();
 
 	session_load ();	
 
@@ -238,9 +230,7 @@ main(int argc, char **argv)
 	panel_session_setup_config_sync ();
 
 	/* add some timeouts */
-	gtk_timeout_add (10*1000, menu_age_timeout, NULL);
-
-	status_applet_create_offscreen ();
+	g_timeout_add (10*1000, menu_age_timeout, NULL);
 
 	gtk_main ();
 
